==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/contract_statuses_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::ContractStatusesController < AccountsManagementController
    # GET /documents/contract_statuses
    # GET /documents/contract_statuses.json
    def index
      @documents_contract_statuses = Documents::ContractStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_contract_statuses }
      end
    end

    # GET /documents/contract_statuses/1
    # GET /documents/contract_statuses/1.json
    def show
      @documents_contract_status = Documents::ContractStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_contract_status }
      end
    end

    # GET /documents/contract_statuses/new
    # GET /documents/contract_statuses/new.json
    def new
      @documents_contract_status = Documents::ContractStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_contract_status }
      end
    end

    # GET /documents/contract_statuses/1/edit
    def edit
      @documents_contract_status = Documents::ContractStatus.find(params[:id])
    end

    # POST /documents/contract_statuses
    # POST /documents/contract_statuses.json
    def create
      @documents_contract_status = Documents::ContractStatus.new(params[:documents_contract_status])

      respond_to do |format|
        if @documents_contract_status.save
          format.html { redirect_to @documents_contract_status, :notice => 'Contract status was successfully created.' }
          format.json { render :json => @documents_contract_status, :status => :created, :location => @documents_contract_status }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_contract_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/contract_statuses/1
    # PUT /documents/contract_statuses/1.json
    def update
      @documents_contract_status = Documents::ContractStatus.find(params[:id])

      respond_to do |format|
        if @documents_contract_status.update_attributes(params[:documents_contract_status])
          format.html { redirect_to @documents_contract_status, :notice => 'Contract status was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_contract_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/contract_statuses/1
    # DELETE /documents/contract_statuses/1.json
    def destroy
      @documents_contract_status = Documents::ContractStatus.find(params[:id])
      @documents_contract_status.destroy

      respond_to do |format|
        format.html { redirect_to documents_contract_statuses_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/contract_statuses_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::ContractStatusesController < AccountsManagementController
    # GET /documents/contract_statuses
    # GET /documents/contract_statuses.json
    def index
      @documents_contract_statuses = Documents::ContractStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_contract_statuses }
      end
    end

    # GET /documents/contract_statuses/1
    # GET /documents/contract_statuses/1.json
    def show
      @documents_contract_status = Documents::ContractStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_contract_status }
      end
    end

    # GET /documents/contract_statuses/new
    # GET /documents/contract_statuses/new.json
    def new
      @documents_contract_status = Documents::ContractStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_contract_status }
      end
    end

    # GET /documents/contract_statuses/1/edit
    def edit
      @documents_contract_status = Documents::ContractStatus.find(params[:id])
    end

    # POST /documents/contract_statuses
    # POST /documents/contract_statuses.json
    def create
      @documents_contract_status = Documents::ContractStatus.new(params[:documents_contract_status])

      respond_to do |format|
        if @documents_contract_status.save
          format.html { redirect_to @documents_contract_status, notice: 'Contract status was successfully created.' }
          format.json { render json: @documents_contract_status, status: :created, location: @documents_contract_status }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_contract_status.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/contract_statuses/1
    # PUT /documents/contract_statuses/1.json
    def update
      @documents_contract_status = Documents::ContractStatus.find(params[:id])

      respond_to do |format|
        if @documents_contract_status.update_attributes(params[:documents_contract_status])
          format.html { redirect_to @documents_contract_status, notice: 'Contract status was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_contract_status.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/contract_statuses/1
    # DELETE /documents/contract_statuses/1.json
    def destroy
      @documents_contract_status = Documents::ContractStatus.find(params[:id])
      @documents_contract_status.destroy

      respond_to do |format|
        format.html { redirect_to documents_contract_statuses_url }
        format.json { head :no_content }
      end
    end
  end
end
